package Org::Element::Comment;

use 5.010;
use locale;
use Moo;
extends 'Org::Element';

our $VERSION = '0.17'; # VERSION

1;
# ABSTRACT: Represent Org comment


=pod

=head1 NAME

Org::Element::Comment - Represent Org comment

=head1 VERSION

version 0.17

=head1 DESCRIPTION

Derived from L<Org::Element>.

=head1 ATTRIBUTES

=head1 METHODS

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__END__

